@@ -12,7 +12,9 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <http://www.gnu.org/licenses/> or
+    write to the Free Software Foundation, 51 Franklin Street, Fifth Floor, 
+    Boston, MA 02110-1301, USA
 */
 
 #ifndef STOP_H
